@@ -26,17 +26,17 @@ if(len(flist)==0):	#for those who use make
 RGFCLib = ctypes.cdll.LoadLibrary(dir_path + os.path.sep + flist[0])
 
 '''
-void islandRemoval(unsigned char* inMask, unsigned char* labelMap, 
-					  unsigned int X, unsigned int Y, 
-					  unsigned int islandSizeThreshold)
+void islandRemoval(char* inMask, char* labelMap, 
+					  int X, int Y, 
+					  int islandSizeThreshold)
 '''
 RGFCLib.islandRemoval.argtypes = [
-                np.ctypeslib.ndpointer(ctypes.c_uint8, flags='C_CONTIGUOUS'),
-                np.ctypeslib.ndpointer(ctypes.c_uint8, flags='C_CONTIGUOUS'),
-                ctypes.c_uint32, ctypes.c_uint32, ctypes.c_uint32]
+                np.ctypeslib.ndpointer(ctypes.c_int8, flags='C_CONTIGUOUS'),
+                np.ctypeslib.ndpointer(ctypes.c_int8, flags='C_CONTIGUOUS'),
+                ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
   
 '''
-void indexCheck(float* inTensor, float* targetLoc, unsigned int X, unsigned int Y, unsigned int Z)
+void indexCheck(float* inTensor, float* targetLoc, int X, int Y, int Z)
 '''
 RGFCLib.indexCheck.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
@@ -44,35 +44,35 @@ RGFCLib.indexCheck.argtypes = [
                 ctypes.c_int, ctypes.c_int, ctypes.c_float]
 
 '''
-float MSSE(float *error, unsigned int vecLen, float MSSE_LAMBDA, unsigned int k, float minimumResidual)
+float MSSE(float *error, int vecLen, float MSSE_LAMBDA, int k, float minimumResidual)
 '''
 RGFCLib.MSSE.restype = ctypes.c_float
 RGFCLib.MSSE.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                ctypes.c_uint, ctypes.c_float, ctypes.c_uint, ctypes.c_float ]
+                ctypes.c_int, ctypes.c_float, ctypes.c_int, ctypes.c_float ]
 
 '''
-float MSSEWeighted(float* error, float* weights, unsigned int vecLen, 
-                   float MSSE_LAMBDA, unsigned int k, float minimumResidual)
+float MSSEWeighted(float* error, float* weights, int vecLen, 
+                   float MSSE_LAMBDA, int k, float minimumResidual)
 '''
 RGFCLib.MSSEWeighted.restype = ctypes.c_float
 RGFCLib.MSSEWeighted.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                ctypes.c_uint, ctypes.c_float, ctypes.c_uint, ctypes.c_float ]
+                ctypes.c_int, ctypes.c_float, ctypes.c_int, ctypes.c_float ]
 
 '''
 void fitValue(float* inVec,
 			  float* inWeights,
 			  float* modelParams,
 			  float theta,
-			  unsigned int inN,
+			  int inN,
               float likelyRatio,
 			  float certainRatio,
               float MSSE_LAMBDA,
-			  unsigned char optIters,
+			  char optIters,
               float minimumResidual,
-			  unsigned int downSampledSize);
+			  int downSampledSize);
 '''
 RGFCLib.fitValue.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
@@ -83,7 +83,7 @@ RGFCLib.fitValue.argtypes = [
                 ctypes.c_float, 
                 ctypes.c_float, 
                 ctypes.c_float, 
-                ctypes.c_uint8, 
+                ctypes.c_int8, 
                 ctypes.c_float, 
                 ctypes.c_int]
 
@@ -92,13 +92,13 @@ void fitValue2Skewed(float* inVec,
 			         float* inWeights,
 			         float* modelParams,
 			         float theta,
-			         unsigned int inN,
+			         int inN,
 					 float likelyRatio,
 			         float certainRatio,
                      float MSSE_LAMBDA,
-			         unsigned char optIters,
+			         char optIters,
                      float minimumResidual,
-			         unsigned int downSampledSize);
+			         int downSampledSize);
 '''                    
 RGFCLib.fitValue2Skewed.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
@@ -109,27 +109,27 @@ RGFCLib.fitValue2Skewed.argtypes = [
                 ctypes.c_float, 
                 ctypes.c_float, 
                 ctypes.c_float, 
-                ctypes.c_uint8, 
+                ctypes.c_int8, 
                 ctypes.c_float, 
                 ctypes.c_int]
 
 
 '''
 void medianOfFits(float *vec, float *weights, 
-                  float *modelParams, float theta, unsigned int N,
-                  float likelyRatio_min, float likelyRatio_max, unsigned int numSamples, float sampleRatio,
-                  float MSSE_LAMBDA, unsigned char optIters, float minimumResidual) 
+                  float *modelParams, float theta, int N,
+                  float likelyRatio_min, float likelyRatio_max, int numSamples, float sampleRatio,
+                  float MSSE_LAMBDA, char optIters, float minimumResidual) 
 '''
 RGFCLib.medianOfFits.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                ctypes.c_float, ctypes.c_uint32, 
-                ctypes.c_float, ctypes.c_float, ctypes.c_uint32, ctypes.c_float,   
-                ctypes.c_float, ctypes.c_uint8, ctypes.c_float]                
+                ctypes.c_float, ctypes.c_int32, 
+                ctypes.c_float, ctypes.c_float, ctypes.c_int32, ctypes.c_float,   
+                ctypes.c_float, ctypes.c_int8, ctypes.c_float]                
 
 '''
-void RobustAlgebraicLineFitting(float* x, float* y, float* mP, unsigned int N,
+void RobustAlgebraicLineFitting(float* x, float* y, float* mP, int N,
 							  float likelyRatio, float certainRatio, float MSSE_LAMBDA)
 '''                
 RGFCLib.RobustAlgebraicLineFitting.argtypes = [
@@ -141,37 +141,37 @@ RGFCLib.RobustAlgebraicLineFitting.argtypes = [
 
 '''
 void RobustAlgebraicLineFittingTensor(float *inTensorX, float *inTensorY, 
-                                        float *modelParamsMap, unsigned int N,
-                                        unsigned int X, unsigned int Y, 
+                                        float *modelParamsMap, int N,
+                                        int X, int Y, 
                             float likelyRatio, float certainRatio, float MSSE_LAMBDA)
 '''
 RGFCLib.RobustAlgebraicLineFittingTensor.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                ctypes.c_uint, ctypes.c_uint, ctypes.c_uint,
+                ctypes.c_int, ctypes.c_int, ctypes.c_int,
                 ctypes.c_float, ctypes.c_float, ctypes.c_float]                
                 
 '''
 void fitValueTensor(float* inTensor, float* inWeights, float* modelParamsMap,
-					unsigned int N, unsigned int X, unsigned int Y,
+					int N, int X, int Y,
 					float likelyRatio, float certainRatio, float MSSE_LAMBDA,
-					unsigned char optIters, float minimumResidual,
-					unsigned int downSampledSize);
+					char optIters, float minimumResidual,
+					int downSampledSize);
 '''
 RGFCLib.fitValueTensor.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                ctypes.c_uint32, ctypes.c_uint32, ctypes.c_uint32,
+                ctypes.c_int32, ctypes.c_int32, ctypes.c_int32,
                 ctypes.c_float, ctypes.c_float, ctypes.c_float, 
-                ctypes.c_uint8, ctypes.c_float, ctypes.c_uint32]
+                ctypes.c_int8, ctypes.c_float, ctypes.c_int32]
 
 '''
 void RobustAlgebraicPlaneFitting(float* x, float* y, float* z, float* mP, float* mP_Init,
-							unsigned int N, float likelyRatio, float certainRatio,
-							float MSSE_LAMBDA, unsigned char stretch2CornersOpt, 
-							float minimumResidual, unsigned char optIters)
+							int N, float likelyRatio, float certainRatio,
+							float MSSE_LAMBDA, char stretch2CornersOpt, 
+							float minimumResidual, char optIters)
 '''
 RGFCLib.RobustAlgebraicPlaneFitting.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
@@ -180,104 +180,104 @@ RGFCLib.RobustAlgebraicPlaneFitting.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 ctypes.c_int, ctypes.c_float, ctypes.c_float, 
-                ctypes.c_float, ctypes.c_uint8, ctypes.c_float, ctypes.c_uint8]
+                ctypes.c_float, ctypes.c_int8, ctypes.c_float, ctypes.c_int8]
                 
 '''
-void RSGImage(float* inImage, unsigned char* inMask, float *modelParamsMap,
-				unsigned int winX, unsigned int winY,
-				unsigned int X, unsigned int Y,
+void RSGImage(float* inImage, char* inMask, float *modelParamsMap,
+				int winX, int winY,
+				int X, int Y,
 				float likelyRatio, float certainRatio,
-				float MSSE_LAMBDA, unsigned char stretch2CornersOpt,
-				unsigned char numModelParams, unsigned char optIters,
+				float MSSE_LAMBDA, char stretch2CornersOpt,
+				char numModelParams, char optIters,
                 float minimumResidual)
 '''                
 RGFCLib.RSGImage.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                np.ctypeslib.ndpointer(ctypes.c_uint8, flags='C_CONTIGUOUS'),
+                np.ctypeslib.ndpointer(ctypes.c_int8, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                ctypes.c_uint32, ctypes.c_uint32, 
-                ctypes.c_uint32, ctypes.c_uint32, 
+                ctypes.c_int32, ctypes.c_int32, 
+                ctypes.c_int32, ctypes.c_int32, 
                 ctypes.c_float, ctypes.c_float, 
-                ctypes.c_float, ctypes.c_uint8, 
-                ctypes.c_uint8, ctypes.c_uint8, ctypes.c_float]
+                ctypes.c_float, ctypes.c_int8, 
+                ctypes.c_int8, ctypes.c_int8, ctypes.c_float]
        
 '''
-void RSGImage_by_Image_Tensor(float* inImage_Tensor, unsigned char* inMask_Tensor,
+void RSGImage_by_Image_Tensor(float* inImage_Tensor, char* inMask_Tensor,
 						float *model_mean, float *model_std,
-						unsigned int winX, unsigned int winY,
-						unsigned int N, unsigned int X, unsigned int Y,
+						int winX, int winY,
+						int N, int X, int Y,
 						float likelyRatio, float certainRatio,
-						float MSSE_LAMBDA, unsigned char stretch2CornersOpt,
-						unsigned char numModelParams, unsigned char optIters,
+						float MSSE_LAMBDA, char stretch2CornersOpt,
+						char numModelParams, char optIters,
                         float minimumResidual)
 '''
 RGFCLib.RSGImage_by_Image_Tensor.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                np.ctypeslib.ndpointer(ctypes.c_uint8, flags='C_CONTIGUOUS'),
+                np.ctypeslib.ndpointer(ctypes.c_int8, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                ctypes.c_uint32, ctypes.c_uint32, 
-                ctypes.c_uint32, ctypes.c_uint32, ctypes.c_uint32,
+                ctypes.c_int32, ctypes.c_int32, 
+                ctypes.c_int32, ctypes.c_int32, ctypes.c_int32,
                 ctypes.c_float, ctypes.c_float, 
-                ctypes.c_float, ctypes.c_uint8, 
-                ctypes.c_uint8, ctypes.c_uint8, ctypes.c_float]
+                ctypes.c_float, ctypes.c_int8, 
+                ctypes.c_int8, ctypes.c_int8, ctypes.c_float]
 
 '''
-void fitBackgroundRadially(float* inImage, unsigned char* inMask,
+void fitBackgroundRadially(float* inImage, char* inMask,
                            float* modelParamsMap, float* vecMP,
-                           unsigned int minRes,
-                           unsigned int maxRes,
-                           unsigned int shellWidth,
-                           unsigned int stride,
-                           unsigned int X_Cent,
-                           unsigned int Y_Cent,
-                           unsigned char includeCenter,
-                           unsigned int finiteSampleBias,
-                           unsigned int X, unsigned int Y,
+                           int minRes,
+                           int maxRes,
+                           int shellWidth,
+                           int stride,
+                           int X_Cent,
+                           int Y_Cent,
+                           char includeCenter,
+                           int finiteSampleBias,
+                           int X, int Y,
                            float likelyRatio, float certainRatio,
                            float MSSE_LAMBDA,
-                           unsigned char optIters,
+                           char optIters,
                            float minimumResidual);
 '''
 
 RGFCLib.fitBackgroundRadially.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                np.ctypeslib.ndpointer(ctypes.c_uint8, flags='C_CONTIGUOUS'),
+                np.ctypeslib.ndpointer(ctypes.c_int8, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                ctypes.c_uint32, ctypes.c_uint32, ctypes.c_uint32, 
-                ctypes.c_uint32, ctypes.c_uint32, ctypes.c_uint32,
-                ctypes.c_uint8, ctypes.c_uint32, 
-                ctypes.c_uint32, ctypes.c_uint32, 
+                ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, 
+                ctypes.c_int32, ctypes.c_int32, ctypes.c_int32,
+                ctypes.c_int8, ctypes.c_int32, 
+                ctypes.c_int32, ctypes.c_int32, 
                 ctypes.c_float, ctypes.c_float, 
-                ctypes.c_float, ctypes.c_uint8, ctypes.c_float]
+                ctypes.c_float, ctypes.c_int8, ctypes.c_float]
 
 '''
 void fitBackgroundCylindrically(float* inTensor,
-								unsigned char* inMask,
+								char* inMask,
                                 float* modelParamsMap,
 								float* vecMP,
-                                unsigned int minRes,
-                                unsigned int maxRes,
-                                unsigned int shellWidth,
-                                unsigned char includeCenter,
-                                unsigned int finiteSampleBias,
-								unsigned int N,
-                                unsigned int X,
-								unsigned int Y,
+                                int minRes,
+                                int maxRes,
+                                int shellWidth,
+                                char includeCenter,
+                                int finiteSampleBias,
+								int N,
+                                int X,
+								int Y,
                                 float likelyRatio,
 								float certainRatio,
                                 float MSSE_LAMBDA,
-                                unsigned char optIters,
+                                char optIters,
 						        float minimumResidual)
 '''
 RGFCLib.fitBackgroundCylindrically.argtypes = [
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                np.ctypeslib.ndpointer(ctypes.c_uint8, flags='C_CONTIGUOUS'),
+                np.ctypeslib.ndpointer(ctypes.c_int8, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
                 np.ctypeslib.ndpointer(ctypes.c_float, flags='C_CONTIGUOUS'),
-                ctypes.c_uint32, ctypes.c_uint32, ctypes.c_uint32, 
-                ctypes.c_uint8, ctypes.c_uint32, 
-                ctypes.c_uint32, ctypes.c_uint32, ctypes.c_uint32, 
+                ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, 
+                ctypes.c_int8, ctypes.c_int32, 
+                ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, 
                 ctypes.c_float, ctypes.c_float, 
-                ctypes.c_float, ctypes.c_uint8, ctypes.c_float]
+                ctypes.c_float, ctypes.c_int8, ctypes.c_float]
